@@ -208,6 +208,7 @@ static void ctk_event_class_init(CtkEventClass *ctk_event_class)
     MAKE_SIGNAL(NV_CTRL_PCI_FUNCTION);
     MAKE_SIGNAL(NV_CTRL_FRAMELOCK_FPGA_REVISION);
     MAKE_SIGNAL(NV_CTRL_FRAMELOCK_FIRMWARE_VERSION);
+    MAKE_SIGNAL(NV_CTRL_FRAMELOCK_FIRMWARE_MINOR_VERSION);
     MAKE_SIGNAL(NV_CTRL_MAX_SCREEN_WIDTH);
     MAKE_SIGNAL(NV_CTRL_MAX_SCREEN_HEIGHT);
     MAKE_SIGNAL(NV_CTRL_MAX_DISPLAYS);
@@ -345,6 +346,7 @@ static void ctk_event_class_init(CtkEventClass *ctk_event_class)
     MAKE_SIGNAL(NV_CTRL_DISPLAYPORT_CONNECTOR_TYPE);
     MAKE_SIGNAL(NV_CTRL_DISPLAYPORT_IS_MULTISTREAM);
     MAKE_SIGNAL(NV_CTRL_DISPLAYPORT_SINK_IS_AUDIO_CAPABLE);
+    MAKE_SIGNAL(NV_CTRL_SHOW_GRAPHICS_VISUAL_INDICATOR);
 #undef MAKE_SIGNAL
 
     /*
@@ -354,7 +356,7 @@ static void ctk_event_class_init(CtkEventClass *ctk_event_class)
      * knows about.
      */
 
-#if NV_CTRL_LAST_ATTRIBUTE != NV_CTRL_FRAMELOCK_FIRMWARE_VERSION
+#if NV_CTRL_LAST_ATTRIBUTE != NV_CTRL_SHOW_GRAPHICS_VISUAL_INDICATOR
 #warning "There are attributes that do not emit signals!"
 #endif
 
@@ -408,9 +410,10 @@ static void ctk_event_class_init(CtkEventClass *ctk_event_class)
     MAKE_STRING_SIGNAL(NV_CTRL_STRING_GPU_UUID);
     MAKE_STRING_SIGNAL(NV_CTRL_STRING_GPU_UTILIZATION);
     MAKE_STRING_SIGNAL(NV_CTRL_STRING_MULTIGPU_MODE);
+    MAKE_STRING_SIGNAL(NV_CTRL_STRING_PRIME_OUTPUTS_DATA);
 #undef MAKE_STRING_SIGNAL
 
-#if NV_CTRL_STRING_LAST_ATTRIBUTE != NV_CTRL_STRING_MULTIGPU_MODE
+#if NV_CTRL_STRING_LAST_ATTRIBUTE != NV_CTRL_STRING_PRIME_OUTPUTS_DATA
 #warning "There are attributes that do not emit signals!"
 #endif
 
